[jbpm-commits] JBoss JBPM SVN: r2041 - jbpm4/pvm/trunk/modules/core/src/main/java/org/jbpm/pvm.

do-not-reply at jboss.org do-not-reply at jboss.org
Thu Aug 28 10:29:10 EDT 2008


Author: tom.baeyens at jboss.com
Date: 2008-08-28 10:29:09 -0400 (Thu, 28 Aug 2008)
New Revision: 2041

Modified:
   jbpm4/pvm/trunk/modules/core/src/main/java/org/jbpm/pvm/ExecutionService.java
Log:
finished renaming key to id in some of the parameters and javadocs

Modified: jbpm4/pvm/trunk/modules/core/src/main/java/org/jbpm/pvm/ExecutionService.java
===================================================================
--- jbpm4/pvm/trunk/modules/core/src/main/java/org/jbpm/pvm/ExecutionService.java	2008-08-28 14:17:03 UTC (rev 2040)
+++ jbpm4/pvm/trunk/modules/core/src/main/java/org/jbpm/pvm/ExecutionService.java	2008-08-28 14:29:09 UTC (rev 2041)
@@ -32,26 +32,26 @@
 public interface ExecutionService {
 
   /** starts a new execution for the ProcessDefinition with the given processDefinitionDbid.
-   * @param processDefinitionKey the {@link ProcessDefinition#getKey() unique key} of the process definition. */
-  Execution startExecution(String processDefinitionKey);
+   * @param processDefinitionId the {@link ProcessDefinition#getId() unique id} of the process definition. */
+  Execution startExecution(String processDefinitionId);
   
   /** starts a new execution for the ProcessDefinition with the given processDefinitionDbid. 
    * @param processDefinitionKey the {@link ProcessDefinition#getKey() unique key} of the process definition.
    * @param executionRef is a user provided reference for the new execution that must be unique over all 
    *    process versions with the same name. */
-  Execution startExecution(String processDefinitionKey, String executionRef);
+  Execution startExecution(String processDefinitionId, String executionKey);
 
   /** starts a new execution for the ProcessDefinition with the given processDefinitionDbid. 
    * @param processDefinitionKey the {@link ProcessDefinition#getKey() unique key} of the process definition.
    * @param variables are the initial values of the process variables that will be set before the execution starts. */
-  Execution startExecution(String processDefinitionKey, Map<String, Object> variables);
+  Execution startExecution(String processDefinitionId, Map<String, Object> variables);
 
   /** starts a new execution for the ProcessDefinition with the given processDefinitionDbid.
    * @param processDefinitionKey the {@link ProcessDefinition#getKey() unique key} of the process definition.
    * @param variables are the initial values of the process variables that will be set before the execution starts.
    * @param executionRef is a user provided reference for the new execution that must be unique over all 
    *    process versions with the same name. */
-  Execution startExecution(String processDefinitionKey, Map<String, Object> variables, String executionRef);
+  Execution startExecution(String processDefinitionId, Map<String, Object> variables, String executionKey);
 
   /** starts a new execution in the latest version of the given process definition.
   * @param processDefinitionName is the name of the process definition for which the latest version will be taken. */ 
@@ -59,9 +59,9 @@
 
   /** starts a new execution in the latest version of the given processDefinitionName.
    * @param processDefinitionName is the name of the process definition for which the latest version will be taken. 
    * @param executionRef is a user provided reference for the new execution that must be unique over all 
    *    process versions with the same name. */
-  Execution startExecutionInLatest(String processDefinitionName, String executionRef);
+  Execution startExecutionInLatest(String processDefinitionName, String executionKey);
 
   /** starts a new execution in the latest version of the given processDefinitionName. 
    * @param processDefinitionName is the name of the process definition for which the latest version will be taken. 
@@ -71,9 +71,9 @@
   /** starts a new execution in the latest version of the given processDefinitionName. 
    * @param processDefinitionName is the name of the process definition for which the latest version will be taken. 
    * @param variables are the initial values of the process variables that will be set before the execution starts.
    * @param executionRef is a user provided reference for the new execution that must be unique over all 
    *    process versions with the same name. */
-  Execution startExecutionInLatest(String processDefinitionName, Map<String, Object> variables, String executionRef);
+  Execution startExecutionInLatest(String processDefinitionName, Map<String, Object> variables, String executionKey);
 
   /** the execution with the given database primary key */
   // TODO REMOVE
@@ -32,26 +32,26 @@
   
   /** starts a new execution for the ProcessDefinition with the given processDefinitionDbid. 
-   * @param processDefinitionKey the {@link ProcessDefinition#getKey() unique key} of the process definition.
-   * @param executionRef is a user provided reference for the new execution that must be unique over all 
+   * @param processDefinitionId the {@link ProcessDefinition#getId() unique id} of the process definition.
+   * @param executionKey is a user provided reference for the new execution that must be unique over all 
    *    process versions with the same name. */
@@ -32,26 +32,26 @@
 
   /** starts a new execution for the ProcessDefinition with the given processDefinitionDbid. 
-   * @param processDefinitionKey the {@link ProcessDefinition#getKey() unique key} of the process definition.
+   * @param processDefinitionId the {@link ProcessDefinition#getId() unique id} of the process definition.
    * @param variables are the initial values of the process variables that will be set before the execution starts. */
@@ -32,26 +32,26 @@
 
   /** starts a new execution for the ProcessDefinition with the given processDefinitionDbid.
-   * @param processDefinitionKey the {@link ProcessDefinition#getKey() unique key} of the process definition.
+   * @param processDefinitionId the {@link ProcessDefinition#getId() unique id} of the process definition.
    * @param variables are the initial values of the process variables that will be set before the execution starts.
@@ -32,26 +32,26 @@
    * @param variables are the initial values of the process variables that will be set before the execution starts.
-   * @param executionRef is a user provided reference for the new execution that must be unique over all 
+   * @param executionKey is a user provided reference for the new execution that must be unique over all 
    *    process versions with the same name. */
@@ -59,9 +59,9 @@
   /** starts a new execution in the latest version of the given processDefinitionName.
    * @param processDefinitionName is the name of the process definition for which the latest version will be taken. 
-   * @param executionRef is a user provided reference for the new execution that must be unique over all 
+   * @param executionKey is a user provided reference for the new execution that must be unique over all 
    *    process versions with the same name. */
@@ -71,9 +71,9 @@
    * @param processDefinitionName is the name of the process definition for which the latest version will be taken. 
    * @param variables are the initial values of the process variables that will be set before the execution starts.
-   * @param executionRef is a user provided reference for the new execution that must be unique over all 
+   * @param executionKey is a user provided reference for the new execution that must be unique over all 
    *    process versions with the same name. */




More information about the jbpm-commits mailing list